==> v0.10.5-beta.tar.gz: j2s/lib/src/stdlib/primordials.ts <==
const buffSymbol: unique symbol = undefined as any;

export interface InternalBuffer {
	length: number;
	[buffSymbol]: "buffer";
}

export interface SymbolPrimordials {
	makeSymbol(name: string): symbol;
	getSymbol(name: string): symbol;
	getSymbolKey(symbol: symbol): string | undefined;
	getSymbolDescription(symbol: symbol): string;
}
export interface NumberPrimordials {
	NaN: number;
	Infinity: number;
	PI: number;
	E: number;

	parseInt(raw: string | number, radix?: number): number;
	parseFloat(raw: string | number): number;
	isNaN(num: number): boolean;

	pow(a: number, b: number): number;
	log(val: number): number;
}
export interface StringPrimordials {
	stringBuild(parts: string[]): string;
	fromCharCode(char: number): string;
	fromCodePoint(char: number): string;
	toCharCode(char: string): number;
	toCodePoint(char: string, i: number): number;
	indexOf(str: string, search: string, start: number, reverse?: boolean): number;
	substring(str: string, start: number, end: number): string;
	lower(str: string): string;
	upper(str: string): string;
}
export interface ObjectPrimordials {
	defineProperty(obj: object, key: string | number | symbol, conf: { g?: Function, s?: Function, e?: boolean, c?: boolean }): boolean;
	defineField(obj: object, key: string | number | symbol, conf: { v?: any, e?: boolean, c?: boolean, w?: boolean }): boolean;
	getOwnMember(obj: object, key: any): PropertyDescriptor | undefined;
	getMembers(obj: object, own: boolean, onlyEnumerable: boolean): string[];
	getSymbolMembers(obj: object, own: boolean, onlyEnumerable: boolean): symbol[];
	getPrototype(obj: object): object | undefined;
	setPrototype(obj: object, proto?: object): object;
	preventExt(obj: object): void;
	seal(obj: object): void;
	freeze(obj: object): void;

	isArray(obj: any): obj is any[];
	subarray(arr: any[], start: number, end: number): any[];

	memcpy(src: any[], dst: any[], srcI: number, dstI: number, n: number): void;
	sort(arr: any[], cb: Function): any[];
}
export interface BufferPrimordials {
	buff(n: number): InternalBuffer;
	backer(arr: number[]): InternalBuffer;
	start(arr: number[]): number;
	end(arr: number[]): number;

	uint8(buff: InternalBuffer, start: number, end: number): number[];
	int8(buff: InternalBuffer, start: number, end: number): number[];
	int32(buff: InternalBuffer, start: number, end: number): number[];

	isUint8(val: any): val is number[];
	isInt8(val: any): val is number[];
	isInt32(val: any): val is number[];
	is(val: any): val is number[];
	isBuff(val: any): val is InternalBuffer;
}
export interface FunctionPrimordials {
	invokeType(args: IArguments, self: any): "new" | "call";
	invokeTypeInfer(): "new" | "call";
	target(): Function | null | undefined;
	setConstructable(func: Function, flag: boolean): void;
	setCallable(func: Function, flag: boolean): void;
	invoke(func: Function, self: any, args: any[]): any;
	construct(func: Function, self: any, args: any[]): any;
}
export interface JSONPrimordials {
	parse(data: string): any;
	stringify(data: any): string;
}

export interface Primordials {
	symbol: SymbolPrimordials;
	number: NumberPrimordials;
	string: StringPrimordials;
	object: ObjectPrimordials;
	function: FunctionPrimordials;
	json: JSONPrimordials;
	buffer: BufferPrimordials;
	map: new (weak?: boolean) => {
		get(key: any): any;
		has(key: any): boolean;
		set(key: any, val: any): void;
		delete(key: any): void;
		keys(): any[];
		clear(): void;
		size(): number;
	};

	regex: new (source: string, multiline?: boolean, noCase?: boolean, dotall?: boolean, unicode?: boolean, unicodeClass?: boolean) => {
		exec(target: string, offset: number, indices: boolean): { matches: RegExpMatchArray, end: number } | null;
		groupCount(): number;
	};
	compile(src: string, filename?: string): Function;
	setGlobalPrototypes(prototype: Record<string, any>): void;
	now(): number;
	next(func: () => void): void;
	schedule(func: () => void, delay: number): () => void;
	setIntrinsic(key: string, val: any): void;
}

// prevent optimization to "undefined", which doesn't exist yet
globalThis.undefined = ({} as any).bogus;
export const target = (globalThis as any).target;
export const primordials: Primordials = (globalThis as any).primordials;

export const {
	symbol,
	number,
	string,
	object,
	buffer,
	function: func,
	json,
	map,
	regex,
	setGlobalPrototypes,
	compile,
	now,
	next,
	schedule,
	setIntrinsic,
} = primordials;

export type regex = InstanceType<typeof regex>;

==> v0.10.8-beta.tar.gz: j2s/lib/src/stdlib/primordials.ts <==
const buffSymbol: unique symbol = undefined as any;

export interface InternalBuffer {
	length: number;
	[buffSymbol]: "buffer";
}

export interface SymbolPrimordials {
	makeSymbol(name: string): symbol;
	getSymbol(name: string): symbol;
	getSymbolKey(symbol: symbol): string | undefined;
	getSymbolDescription(symbol: symbol): string;
}
export interface NumberPrimordials {
	NaN: number;
	Infinity: number;
	PI: number;
	E: number;

	parseInt(raw: string | number, radix?: number): number;
	parseFloat(raw: string | number): number;
	isNaN(num: number): boolean;

	pow(a: number, b: number): number;
	log(val: number): number;
}
export interface StringPrimordials {
	stringBuild(parts: string[]): string;
	fromCharCode(char: number): string;
	fromCodePoint(char: number): string;
	toCharCode(char: string): number;
	toCodePoint(char: string, i: number): number;
	indexOf(str: string, search: string, start: number, reverse?: boolean): number;
	substring(str: string, start: number, end: number): string;
	lower(str: string): string;
	upper(str: string): string;
}
export interface ObjectPrimordials {
	defineProperty(obj: object, key: string | number | symbol, conf: { g?: Function, s?: Function, e?: boolean, c?: boolean }): boolean;
	defineField(obj: object, key: string | number | symbol, conf: { v?: any, e?: boolean, c?: boolean, w?: boolean }): boolean;
	getOwnMember(obj: object, key: any): PropertyDescriptor | undefined;
	getMembers(obj: object, own: boolean, onlyEnumerable: boolean): string[];
	getSymbolMembers(obj: object, own: boolean, onlyEnumerable: boolean): symbol[];
	getPrototype(obj: object): object | undefined;
	setPrototype(obj: object, proto?: object): object;
	preventExt(obj: object): void;
	seal(obj: object): void;
	freeze(obj: object): void;

	isArray(obj: any): obj is any[];
	subarray(arr: any[], start: number, end: number): any[];

	memcpy(src: any[], dst: any[], srcI: number, dstI: number, n: number): void;
	sort(arr: any[], cb: Function): any[];
}
export interface BufferPrimordials {
	buff(n: number): InternalBuffer;
	backer(arr: number[]): InternalBuffer;
	start(arr: number[]): number;
	end(arr: number[]): number;

	uint8(buff: InternalBuffer, start: number, end: number): number[];
	int8(buff: InternalBuffer, start: number, end: number): number[];
	int32(buff: InternalBuffer, start: number, end: number): number[];

	isUint8(val: any): val is number[];
	isInt8(val: any): val is number[];
	isInt32(val: any): val is number[];
	is(val: any): val is number[];
	isBuff(val: any): val is InternalBuffer;
}
export interface FunctionPrimordials {
	invokeType(args: IArguments, self: any): "new" | "call";
	invokeTypeInfer(): "new" | "call";
	target(level?: number): Function | null | undefined;
	setConstructable(func: Function, flag: boolean): void;
	setCallable(func: Function, flag: boolean): void;
	invoke(func: Function, self: any, args: any[]): any;
	construct(func: Function, self: any, args: any[]): any;
}
export interface JSONPrimordials {
	parse(data: string): any;
	stringify(data: any): string;
}

export interface Primordials {
	symbol: SymbolPrimordials;
	number: NumberPrimordials;
	string: StringPrimordials;
	object: ObjectPrimordials;
	function: FunctionPrimordials;
	json: JSONPrimordials;
	buffer: BufferPrimordials;
	map: new (weak?: boolean) => {
		get(key: any): any;
		has(key: any): boolean;
		set(key: any, val: any): void;
		delete(key: any): void;
		keys(): any[];
		clear(): void;
		size(): number;
	};

	regex: new (source: string, multiline?: boolean, noCase?: boolean, dotall?: boolean, unicode?: boolean, unicodeClass?: boolean) => {
		exec(target: string, offset: number, indices: boolean): { matches: RegExpMatchArray, end: number } | null;
		groupCount(): number;
	};
	compile(src: string, filename?: string): Function;
	setGlobalPrototypes(prototype: Record<string, any>): void;
	now(): number;
	next(func: () => void): void;
	schedule(func: () => void, delay: number): () => void;
	setIntrinsic(key: string, val: any): void;
	print(...args: any[]): void;
}

// prevent optimization to "undefined", which doesn't exist yet
globalThis.undefined = ({} as any).bogus;
export const target = (globalThis as any).target;
export const primordials: Primordials = (globalThis as any).primordials;

export const {
	symbol,
	number,
	string,
	object,
	buffer,
	function: func,
	json,
	map,
	regex,
	setGlobalPrototypes,
	compile,
	now,
	next,
	schedule,
	setIntrinsic,
	print,
} = primordials;

export type regex = InstanceType<typeof regex>;
